@@ -70,7 +70,7 @@ cmake \
     -DopenPMD_USE_MPI=${USE_MPI}              \
     -DopenPMD_USE_HDF5=ON       \
     -DopenPMD_USE_ADIOS1=${USE_ADIOS1}        \
-    -DopenPMD_USE_ADIOS2=OFF    \
+    -DopenPMD_USE_ADIOS2=ON     \
     -DopenPMD_USE_PYTHON=ON     \
     -DopenPMD_USE_INTERNAL_PYBIND11=OFF              \
     -DPYTHON_EXECUTABLE:FILEPATH=$(which ${PYTHON})  \
